﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Interop;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Controls.Charts;
using Infragistics.Windows;

namespace ChartInfoStrips
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            this.DataContext = new MainWindowViewModel();
            Loaded += MainWindow_Loaded;
        }

        void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            DataTable dt = ((MainWindowViewModel)this.DataContext).SourceData;
            xAxis.ItemsSource = dt.DefaultView;

            LineSeries series1 = new LineSeries();
            series1.ItemsSource = dt.DefaultView;
            series1.ValueMemberPath = "YAxis";
            series1.XAxis = xAxis;
            series1.YAxis = yAxis;
            series1.MarkerType = MarkerType.None;
            series1.Title = "My Line Series";
            xamDataChart1.Series.Add(series1);

            //Black line at the origin of the Y Axis
            ValueOverlay origin = new ValueOverlay();
            origin.Axis = yAxis;
            origin.Value = 0.0;
            origin.Thickness = 0.75;
            origin.Brush = new SolidColorBrush(Colors.Black);
            origin.LegendItemVisibility = Visibility.Collapsed;
            xamDataChart1.Series.Add(origin);

            xamDataChart1.Series.Add(CreateOverlay(13));
            xamDataChart1.Series.Add(CreateOverlay(33));
            xamDataChart1.Series.Add(CreateOverlay(52));
            xamDataChart1.Series.Add(CreateOverlay(74));
            xamDataChart1.Series.Add(CreateOverlay(95));
            xamDataChart1.Series.Add(CreateOverlay(116));
            xamDataChart1.Series.Add(CreateOverlay(137));
            xamDataChart1.Series.Add(CreateOverlay(158));
            xamDataChart1.Series.Add(CreateOverlay(180));
            xamDataChart1.Series.Add(CreateOverlay(201));
            xamDataChart1.Series.Add(CreateOverlay(223));
            xamDataChart1.Series.Add(CreateOverlay(244));
        }

        private ValueOverlay CreateOverlay(int value = 0)
        {
            ValueOverlay overlay = new ValueOverlay();
            overlay.Axis = hiddenYearXAxis;
            overlay.Value = value;
            overlay.Thickness = 0.75;
            overlay.LegendItemVisibility = Visibility.Collapsed;
            overlay.Brush = new SolidColorBrush(Colors.Black);
            return overlay;
        }

        private void xamDataChart_RefreshCompleted(object sender, EventArgs e)
        {
            if (xamDataChart1.Series.Any())
            {
                // doesn't really matter which series we use for this
                Series series = xamDataChart1.Series[0];
                if (series.RootCanvas != null)
                {
                    HorizontalAxisLabelPanel axisPanel = (HorizontalAxisLabelPanel)Utilities.GetDescendantFromType<HorizontalAxisLabelPanel>(xamDataChart1, false, SearchHorizontalAxisCallback);
                }
            }
        }

        private bool SearchHorizontalAxisCallback(HorizontalAxisLabelPanel dependencyObject)
        {
            // doesn't really matter which series we use for this
            Series series = xamDataChart1.Series[0];
            if (series.RootCanvas != null)
            {
                double pixel = yAxis.ScaleValue(0.0);

                // move the X axis to the correct location
                double axisHeightAdjustment = series.RootCanvas.ActualHeight - pixel;
                dependencyObject.RenderTransform = new TranslateTransform(0.0, -axisHeightAdjustment);
            }

            return false;
        }
    }

    public class MainWindowViewModel : INotifyPropertyChanged
    {
        public DataTable SourceData
        {
            get { return LoadData(); }
        }

        List<string> workingDays = new List<string>() { "Mon", "Tue", "Wed", "Thr", "Fri" };
        
        public DataTable DaysOfWeek
        {
            get
            {
                DataTable dt = new DataTable();
                dt.Columns.Add("Name", typeof(string));
                dt.Columns.Add("Value", typeof(double));

                Random random = new Random();

                foreach (string item in workingDays)
                {
                    dt.Rows.Add(item, random.NextDouble());
                }
                return dt;
            }
        }

        private DataTable LoadData()
        {
            DataTable dt = new DataTable();
            dt.Columns.Add("XAxis", typeof(string));
            dt.Columns.Add("YAxis", typeof(double));

            Random random = new Random();
            double max = 0.2;
            double min = -0.1;
            var directory = System.AppDomain.CurrentDomain.BaseDirectory;
            string path = directory.Replace(@"\bin\Debug\", string.Empty);
            DataSet ds = new DataSet();
            ds.ReadXml(string.Concat(path, @"\MetaData\DaysOfYearMetaData.xml"));
            DataTable newTable = ds.Tables[0];

            foreach (DataRow dr in newTable.Rows)
            {
                dt.Rows.Add(dr["Label"], random.NextDouble() * (max - min) + min);
            }

            return dt;
        }

        #region INotifyPropertyChanged
        public event PropertyChangedEventHandler PropertyChanged;

        protected virtual void OnPropertyChanged(string propertyName)
        {
            PropertyChangedEventHandler handler = this.PropertyChanged;
            if (handler != null)
            {
                var e = new PropertyChangedEventArgs(propertyName);
                handler(this, e);
            }
        }
        #endregion
    }
}
